@@ -36,7 +36,7 @@ public:
 		image = NULL;
 	}
 	LineMarker(const LineMarker &) {
-		// Defined to avoid pxpm being blindly copied, not as real copy constructor
+		// Defined to avoid pxpm being blindly copied, not as a complete copy constructor
 		markType = SC_MARK_CIRCLE;
 		fore = ColourDesired(0,0,0);
 		back = ColourDesired(0xff,0xff,0xff);
@@ -49,22 +49,24 @@ public:
 		delete pxpm;
 		delete image;
 	}
-	LineMarker &operator=(const LineMarker &) {
-		// Defined to avoid pxpm being blindly copied, not as real assignment operator
-		markType = SC_MARK_CIRCLE;
-		fore = ColourDesired(0,0,0);
-		back = ColourDesired(0xff,0xff,0xff);
-		backSelected = ColourDesired(0xff,0x00,0x00);
-		alpha = SC_ALPHA_NOALPHA;
-		delete pxpm;
-		pxpm = NULL;
-		delete image;
-		image = NULL;
+	LineMarker &operator=(const LineMarker &other) {
+		// Defined to avoid pxpm being blindly copied, not as a complete assignment operator
+		if (this != &other) {
+			markType = SC_MARK_CIRCLE;
+			fore = ColourDesired(0,0,0);
+			back = ColourDesired(0xff,0xff,0xff);
+			backSelected = ColourDesired(0xff,0x00,0x00);
+			alpha = SC_ALPHA_NOALPHA;
+			delete pxpm;
+			pxpm = NULL;
+			delete image;
+			image = NULL;
+		}
 		return *this;
 	}
 	void SetXPM(const char *textForm);
 	void SetXPM(const char *const *linesForm);
-	void SetRGBAImage(Point sizeRGBAImage, const unsigned char *pixelsRGBAImage);
+	void SetRGBAImage(Point sizeRGBAImage, float scale, const unsigned char *pixelsRGBAImage);
 	void Draw(Surface *surface, PRectangle &rc, Font &fontForCharacter, typeOfFold tFold, int marginStyle);
 };
 
